==> OB-3.1.2.tar.gz: OB-3.1.2/ob/src/library/SelectReactor.h <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#ifndef OB_SELECT_REACTOR_H
#define OB_SELECT_REACTOR_H

//
// The OBSelectReactor class
//
class OBSelectReactor : public OBReactor
{
    //
    // Hide copy-constructor and asignment operator
    //
    OBSelectReactor(const OBSelectReactor&);
    void operator=(const OBSelectReactor&);

    //
    // If set to true, event dispatching must be stopped
    //
    bool stop_;

    //
    // Struct for an event handler info
    //
    struct HandlerInfo
    {
	OBEventHandler* handler;
	OBMask mask;
	OBHandle handle;
	HandlerInfo* next;
    };

    //
    // Head of the list with all event handler infos
    //
    HandlerInfo* handlerInfoList_;

    //
    // Counter which keeps track of how often the list with event
    // handler infos is currently in use
    //
    CORBA_ULong handlerInfoListUsageCount_;

    //
    // Reap the list of event handler infos
    //
    void reapHandlerInfoList();

    //
    // Set file descriptor sets
    //
    int setFdSets(fd_set&, fd_set&) const;

    //
    // Evaluate file descriptor sets
    //
    void evalFdSets(fd_set&, fd_set&);

protected: // Make the constructor and destructor protected to avoid
           // stupid warning messages from some compilers
    OBSelectReactor();
    virtual ~OBSelectReactor();

public:

    //
    // Get the reactor singleton
    //
    static OBReactor* instance();

    //
    // Register and unregister event handler
    //
    virtual void registerHandler(OBEventHandler*, OBMask, OBHandle);
    virtual void unregisterHandler(OBEventHandler*);

    //
    // Dispatch events
    //
    virtual void dispatch();
    virtual bool dispatchOneEvent(CORBA_Long);

    //
    // Stop event dispatching
    //
    virtual void stop() { stop_ = true; }
};

#endif

==> OB-4.0a2.tar.gz: OB-4.0a2/ob/src/library/SelectReactor.h <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#ifndef OB_SELECT_REACTOR_H
#define OB_SELECT_REACTOR_H

namespace OB
{

//
// The SelectReactor class
//
class SelectReactor : public Reactor
{
    //
    // Hide copy-constructor and assignment operator
    //
    SelectReactor(const SelectReactor&);
    void operator=(const SelectReactor&);

    //
    // If set to true, event dispatching must be stopped
    //
    bool stop_;

    //
    // Struct for an event handler info
    //
    struct HandlerInfo
    {
	EventHandler* handler;
	Mask mask;
	Handle handle;
	HandlerInfo* next;
    };

    //
    // Head of the list with all event handler infos
    //
    HandlerInfo* handlerInfoList_;

    //
    // Counter which keeps track of how often the list with event
    // handler infos is currently in use
    //
    CORBA::ULong handlerInfoListUsageCount_;

    //
    // Reap the list of event handler infos
    //
    void reapHandlerInfoList();

    //
    // Set file descriptor sets
    //
    int setFdSets(fd_set&, fd_set&) const;

    //
    // Evaluate file descriptor sets
    //
    void evalFdSets(fd_set&, fd_set&);

protected: // Make the constructor and destructor protected to avoid
           // stupid warning messages from some compilers
    SelectReactor();
    virtual ~SelectReactor();

public:

    //
    // Get the reactor singleton
    //
    static Reactor* instance();

    //
    // Register and unregister event handler
    //
    virtual void registerHandler(EventHandler*, Mask, Handle);
    virtual void unregisterHandler(EventHandler*);

    //
    // Dispatch events
    //
    virtual void dispatch();
    virtual bool dispatchOneEvent(CORBA::Long);

    //
    // Test to see if an event is available
    //
    virtual bool eventReady();

    //
    // Stop event dispatching
    //
    virtual void stop() { stop_ = true; }
};

} // End of namespace OB

#endif
